==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/sr/globals.php <==
<?php 
regGS("Account", "Налог");
regGS("Items per page", "Ставки по страни");
regGS("Add new", "Додај нови");
regGS("Campsite", "КЕМПСАЈТ");
regGS("Home", "Почетак");
regGS("Logout", "Одјава");
regGS("More...", "Даље...");
regGS("Content", "Садржаји");
regGS("Languages", "Језици");
regGS("Countries", "Државе");
regGS("Templates", "Шаблони");
regGS("Topics", "Теме");
regGS("Configure", "Подешавања");
regGS("Image Archive", "Фото архива");
regGS("Add Article", "Додај текст");
regGS("Fields", "Поља");
regGS("Delete", "Обриши");
regGS("Type", "Тип");
regGS("Name", "Наслов");
regGS("Code", "Код");
regGS("Edit", "Уреди");
regGS("Login", "Пријава");
regGS("Password", "Лозинка");
regGS("Site", "Сајт");
regGS("Path", "Путања");
regGS("Go up", "Ниво изнад");
regGS("URL", "УРЛ");
regGS("Order", "Поредак");
regGS("Hide", "Сакриј");
regGS("Duplicate", "Дупликат");
regGS("Subscription", "Претплата");
regGS("expires", "истиче");
regGS("starts", "почиње");
regGS("before", "пре");
regGS("after", "после");
regGS("on", "у");
regGS("status", "статус");
regGS("active", "активна");
regGS("inactive", "неактивна");
regGS("Subscribers", "Претплатници");
regGS("Staff", "Сарадници");
regGS("Select destination", "Изабери дестинацију");
regGS("No languages", "Нема језика");
regGS("---Select language---", "--- Изабери језик ---");
regGS("No publications", "Нема публикација");
regGS("---Select publication---", "--- Изабери публикацију ---");
regGS("No issues", "Нема издања");
regGS("---Select issue---", "--- Изабери издање ---");
regGS("No sections", "Нема рубрика");
regGS("---Select section---", "--- Изабери рубрику ---");
regGS("No articles", "Нема текстова");
regGS("---Select article---", "--- Изабери текст ---");
regGS("Language", "Језик");
regGS("Country", "Држава");
regGS("Account name", "Име налога");
regGS("Publication", "Публикација");
regGS("Default language", "Основни језик");
regGS("Subscriptions", "Претплате");
regGS("Issue", "Издање");
regGS("Number", "Број");
regGS("Section", "Рубрика");
regGS("Keywords", "Кључне речи");
regGS("Topic", "Тема");
regGS("URL Name", "Скраћено име");
regGS("Left to pay", "Преостало за плаћање");
regGS("Active", "Активна");
regGS("Trial", "Пробна");
regGS("Next", "Следећи");
regGS("Previous", "Претходни");
regGS("Translate", "Преведи");
regGS("View", "Приказ ");
regGS("Scheduled Publishing", "Аутоматско објављивање");
regGS("Time", "Време");
regGS("Action", "Акција");
regGS("Schedule a new action", "Закажи нову акцију");
regGS("Scheduling a new publish action", "Закажи нову акцију објављивања");
regGS("Delete scheduled publish action", "Обриши заказану акцију објављивања");
regGS("Date/Time", "Датум/време");
regGS("You must select an action.", "Морате изабрати акцију");
regGS("You do not have the right to schedule issues or articles for automatic publishing.", "Немате право да заказујете аутоматско објављивање издања и текстова.");
regGS("Front page", "Почетна страна");
regGS("Section page", "Страна рубрике");
regGS("Show on front page", "Прикажи на почетној страни");
regGS("Remove from front page", "Повуци са почетне стране");
regGS("Show on section page", "Прикажи на страни рубрике");
regGS("Remove from section page", "Повуци са стране рубрике");
regGS("Actions", "Акције");
regGS("Publishing", "Објављивање");
regGS("Show", "Прикажи");
regGS("Remove", "Уклони");
regGS("Article Types", "Типови текстова");
regGS("Staff User Types", "Типови сарадника");
regGS("Publications", "Публикације");
regGS("Issues", "Издања");
regGS("Sections", "Рубрике");
regGS("Articles", "Текстови");
regGS("Images", "Слике");
regGS("Change", "Промени");
regGS("Add new issue", "Додај ново издање");
regGS("Section Template", "Шаблон рубрике");
regGS("Article Template", "Шаблон текста");
regGS("Default Language", "Основни језик");
regGS("Paid Period", "Плаћени период");
regGS("Preview", "Преглед");
regGS("You must complete the $1 field.", "Морате попунити поље $1 ");
regGS("Error", "Грешка");
regGS("Invalid input: $1", "Погрешан унос: $1");
regGS("Language does not exist.", "Нема тог језика.");
regGS("Publication does not exist.", "Нема такве публикације.");
regGS("Issue does not exist.", "Нема тог издања.");
regGS("You must select a language.", "Морате изабрати језик.");
regGS("Section does not exist.", "Та рубрика не постоји.");
regGS("No articles.", "Нема текстова.");
regGS("Article does not exist.", "Текст не постоји.");
regGS("Image does not exist.", "Слика не постоји.");
regGS("Access denied", "Забрањен приступ");
regGS("Invalid parameters received", "Примљени су погрешни параметри");
regGS("Add new article", "Додај нови чланак");
regGS("Status", "Статус");
regGS("Published", "Објављен");
regGS("Not published", "Необјављено");
regGS("Submitted", "Предат");
regGS("New", "Нови");
regGS("Article", "Текст");
regGS("Publish", "Објави");
regGS("Unpublish", "Повуци");
regGS("Unlock", "Откључај");
regGS("Uploaded", "Аплоудован");
regGS("(yyyy-mm-dd)", "(гггг-мм-дд)");
regGS("YYYY-MM-DD", "ГГГГ-ММ-ДД");
regGS("Submit", "Пошаљи");
regGS("Image", "Слика");
regGS("Description", "Опис");
regGS("Photographer", "Фотограф");
regGS("Place", "Место");
regGS("Date", "Датум");
regGS("Thumbnail", "Мала слика");
regGS("In use", "Употребљен");
regGS("Additional searches", "Додатне претраге");
regGS("Most Recently Added", "Најновије додате");
regGS("Most Recently Modified", "Најскорије мењане");
regGS("$1 images found", "Пронађено/а је $1 слика");
regGS("Reset search conditions", "Поништи услове претраге");
regGS("Image number", "Број слике");
regGS("Users", "Корисници");
regGS("Restart the template engine", "Рестартуј шаблон-машину");
regGS("The template engine was (re)started.", "Шаблон-машина је рестартована.");
regGS("The template engine could not be restarted! Please verify if the template engine was started by other user than $1.", "Шаблон-машина не може бити рестартована! Проверите да ли је шаблон-машина стартована од стране корсника који није $1.");
regGS("Localizer", "Локализатор");
regGS("Adding new translation", "Додавање новог превода");
regGS("No more languages.", "Нема више језика");
regGS("The $1 field may only contain letters, digits and underscore (_) character.", "Поље $1 може садржати искључиво слова, бројке и доњу црту (_).");
regGS("Add new publication", "Додај нову публикацију");
regGS("Upload new template", "Аплоудуј нови шаблон");
regGS("Add new staff member", "Додај новог сарадника");
regGS("Add new subscriber", "додај новог претплатника");
regGS("Add new user type", "Додај нови тип корисника");
regGS("Add new article type", "Додај нови тип текста");
regGS("Add new country", "Додај државу");
regGS("Add new language", "Додај језик");
regGS("View logs", "Прикажи логове");
regGS("Change your password", "Промени лозинку");
regGS("Your Articles", "Твоји текстови");
regGS("Submitted Articles", "Предати текстови");
regGS("Logs", "Логови");
regGS("There are $1 article(s) left.", "Преоста(л)о је $1 текст(ова)");
regGS("There are $1 issues(s) left.", "Преостало је $1 издања");
regGS("There are $1 section(s) left.", "Преоста(л)о је $1 рубрика");
regGS("There are $1 publication(s) left.", "Преостало(а) је $1 публикација");
regGS("There are $1 countries left.", "Преостало је $1 држава");
regGS("Name <SMALL>(click to edit)</SMALL>", "Име<br><small>(клик за уређивање)</small>");
regGS("Add new subscription", "Додај нову претплату");
regGS("You do not have the right to add subscriptions.", "Немате право да додајете претплате");
regGS("Adding subscription", "Додавање претплате");
regGS("Delete subscription", "Обриши претплату");
regGS("You do not have the right to delete subscriptions.", "Немате право да бришете претплате");
regGS("No such subscription.", "Нема такве претплате");
regGS("Yes", "Да");
regGS("No", "Не");
regGS("Close", "Затвори");
regGS("No issues.", "Нема издања");
regGS("Back to Edit Article", "Назад на детаље текста");
regGS("No topics", "Нема тема");
regGS("You must fill in the $1 field.", "Морате попунити поље $1");
regGS("You do not have the right to add articles.", "Немате право да додајете чланке");
regGS("Start", "Почетак");
regGS("Days", "Дана");
regGS("(YYYY-MM-DD)", "(ГГГГ-ММ-ДД)");
regGS("The sections could not be added successfully. Some of them were already added !", "Рубрике не могу бити додате. Неке од њих већ постоје!");
regGS("Add another", "Настави са додавањем");
regGS("Cancel", "Поништи");
regGS("Done", "Готово");
regGS("OK", "OK");
regGS("Save", "Сними");
regGS("Search", "Тражи");
regGS("Make a selection", "Изаберите");
regGS("You must input a number greater than 0 into the $1 field.", "Морате унети број већи од 0 у поље $1");
regGS("You must input a valid date.", "Морате исправно унети датум");
regGS("Add new field", "Додај ново поље");
regGS("Article automatic publishing schedule", "Распоред аутоматског објављивања чланака");
regGS("Are you sure you want to delete this scheduled action?", "Да ли сте сигурни да желите да обришете заказану акцију?");
regGS("Unlink", "Поништи линк");
regGS("Are you sure you want to delete the image \'$1\'?", "Да ли сте сигурни да желите да обришете слику \'$1\'?");
regGS("No such issue.", "Нема тог издања.");
regGS("Are you sure you want to delete the subscription to the publication $1?", "Да ли сте сигурни да желите да обришете претплату на публикацију $1? ");
regGS("Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.", "Промена у издању $1 не може бити снимљена. Проверите да ли УРЛ име издања '$2'није већ коришћено у публикацији $3.");
regGS("GB", "ГБ");
regGS("MB", "МБ");
regGS("KB", "КБ");
regGS("bytes", "бајтова");
regGS("Attach", "Прикачи");
regGS("Back", "Назад");
regGS("File", "Фајл");
regGS("Save and Close", "Сними и затвори");
regGS("Add", "Додај");
regGS("Select All", "Изабери све");
regGS("Select None", "Изабери ниједан");
regGS("Add Event", "Додајте акцију");
regGS("N/A", "без података");
regGS("On Front Page", "На првој страни");
regGS("On Section Page", "На страни рубрике");
regGS("Created by", "Креирао:");
regGS("Creation date", "Датум креирања");
regGS("User name", "Корисничко име");
regGS("User Types", "Типови корисника");
regGS("Add new user account", "Додај новог корисника");
regGS("Schedule a new publish action", "Закажи нову акцију објављивања");
regGS("User may add/change user accounts and passwords", "Корисник може да додаје/мења корисничке налоге и лозинке");
regGS("User may delete user accounts", "Корисник може да брише корисничке налоге");
regGS("Publication List", "Листа публикација");
regGS("Issue List", "Листа издања");
regGS("Section List", "Листа рубрика");
regGS("All", "Све");
regGS("duplicate", "дуплирај");
regGS("move", "премести");
regGS("Move", "Премести");
regGS("From:", "");
regGS("Date:", "");
regGS("Hidden", "");
regGS("Comments", "");
regGS("Comment", "");
regGS("Approved", "");
regGS("Comment:", "");
regGS("Subject:", "");
regGS("Subject", "");
regGS("Name:", "");
regGS("IP address:", "");
regGS("Email:", "");
regGS("Author:", "");
regGS("Author", "");
regGS("Article name", "");
regGS("Hide article", "");
regGS("Show article", "");
regGS("Article Type Fields", "Поља типа чланка");
regGS("Article Images", "Слике у чланцима");
regGS("Log Messages", "Лог поруке");
regGS("Article Files", "Фајлови уз чланак");
regGS("Article Comments", "");
regGS("Are you sure you want to deactivate the subscription?", "Да ли сте сигурни да желите да деактивирате претплату?");
regGS("Are you sure you want to activate the subscription?", "Да ли сте сигурни да желите да активирате претплату?");
regGS("Other", "");
regGS("No events.", "");
regGS("Default templates", "");
regGS("System Preferences", "");
regGS("The date must be in the future.", "");
regGS("Send", "");
regGS("Thank you.", "");
regGS("Please take a minute to send us an email.", "");
regGS("(optional)", "");
regGS("The URL you entered is invalid: '$1'", "");
?>

==> campsite-2.6.7_5.tbz: campsite/www-common/html/priv/lang/sr/globals.php <==
<?php 
regGS("Account", "Налог");
regGS("Items per page", "Ставки по страни");
regGS("Add new", "Додај нови");
regGS("Campsite", "КЕМПСАЈТ");
regGS("Home", "Почетак");
regGS("Logout", "Одјава");
regGS("More...", "Даље...");
regGS("Content", "Садржаји");
regGS("Languages", "Језици");
regGS("Countries", "Државе");
regGS("Templates", "Шаблони");
regGS("Topics", "Теме");
regGS("Configure", "Подешавања");
regGS("Image Archive", "Фото архива");
regGS("Add Article", "Додај текст");
regGS("Fields", "Поља");
regGS("Delete", "Обриши");
regGS("Type", "Тип");
regGS("Name", "Наслов");
regGS("Code", "Код");
regGS("Edit", "Уреди");
regGS("Login", "Пријава");
regGS("Password", "Лозинка");
regGS("Site", "Сајт");
regGS("Path", "Путања");
regGS("Go up", "Ниво изнад");
regGS("URL", "УРЛ");
regGS("Order", "Поредак");
regGS("Hide", "Сакриј");
regGS("Duplicate", "Дупликат");
regGS("Subscription", "Претплата");
regGS("expires", "истиче");
regGS("starts", "почиње");
regGS("before", "пре");
regGS("after", "после");
regGS("on", "у");
regGS("status", "статус");
regGS("active", "активна");
regGS("inactive", "неактивна");
regGS("Subscribers", "Претплатници");
regGS("Staff", "Сарадници");
regGS("Select destination", "Изабери дестинацију");
regGS("No languages", "Нема језика");
regGS("---Select language---", "--- Изабери језик ---");
regGS("No publications", "Нема публикација");
regGS("---Select publication---", "--- Изабери публикацију ---");
regGS("No issues", "Нема издања");
regGS("---Select issue---", "--- Изабери издање ---");
regGS("No sections", "Нема рубрика");
regGS("---Select section---", "--- Изабери рубрику ---");
regGS("No articles", "Нема текстова");
regGS("---Select article---", "--- Изабери текст ---");
regGS("Language", "Језик");
regGS("Country", "Држава");
regGS("Account name", "Име налога");
regGS("Publication", "Публикација");
regGS("Default language", "Основни језик");
regGS("Subscriptions", "Претплате");
regGS("Issue", "Издање");
regGS("Number", "Број");
regGS("Section", "Рубрика");
regGS("Keywords", "Кључне речи");
regGS("Topic", "Тема");
regGS("URL Name", "Скраћено име");
regGS("Left to pay", "Преостало за плаћање");
regGS("Active", "Активна");
regGS("Trial", "Пробна");
regGS("Next", "Следећи");
regGS("Previous", "Претходни");
regGS("Translate", "Преведи");
regGS("View", "Приказ ");
regGS("Scheduled Publishing", "Аутоматско објављивање");
regGS("Time", "Време");
regGS("Action", "Акција");
regGS("Schedule a new action", "Закажи нову акцију");
regGS("Scheduling a new publish action", "Закажи нову акцију објављивања");
regGS("Delete scheduled publish action", "Обриши заказану акцију објављивања");
regGS("Date/Time", "Датум/време");
regGS("You must select an action.", "Морате изабрати акцију");
regGS("You do not have the right to schedule issues or articles for automatic publishing.", "Немате право да заказујете аутоматско објављивање издања и текстова.");
regGS("Front page", "Почетна страна");
regGS("Section page", "Страна рубрике");
regGS("Show on front page", "Прикажи на почетној страни");
regGS("Remove from front page", "Повуци са почетне стране");
regGS("Show on section page", "Прикажи на страни рубрике");
regGS("Remove from section page", "Повуци са стране рубрике");
regGS("Actions", "Акције");
regGS("Publishing", "Објављивање");
regGS("Show", "Прикажи");
regGS("Remove", "Уклони");
regGS("Article Types", "Типови текстова");
regGS("Staff User Types", "Типови сарадника");
regGS("Publications", "Публикације");
regGS("Issues", "Издања");
regGS("Sections", "Рубрике");
regGS("Articles", "Текстови");
regGS("Images", "Слике");
regGS("Change", "Промени");
regGS("Add new issue", "Додај ново издање");
regGS("Section Template", "Шаблон рубрике");
regGS("Article Template", "Шаблон текста");
regGS("Default Language", "Основни језик");
regGS("Paid Period", "Плаћени период");
regGS("Preview", "Преглед");
regGS("You must complete the $1 field.", "Морате попунити поље $1 ");
regGS("Error", "Грешка");
regGS("Invalid input: $1", "Погрешан унос: $1");
regGS("Language does not exist.", "Нема тог језика.");
regGS("Publication does not exist.", "Нема такве публикације.");
regGS("Issue does not exist.", "Нема тог издања.");
regGS("You must select a language.", "Морате изабрати језик.");
regGS("Section does not exist.", "Та рубрика не постоји.");
regGS("No articles.", "Нема текстова.");
regGS("Article does not exist.", "Текст не постоји.");
regGS("Image does not exist.", "Слика не постоји.");
regGS("Access denied", "Забрањен приступ");
regGS("Invalid parameters received", "Примљени су погрешни параметри");
regGS("Add new article", "Додај нови чланак");
regGS("Status", "Статус");
regGS("Published", "Објављен");
regGS("Not published", "Необјављено");
regGS("Submitted", "Предат");
regGS("New", "Нови");
regGS("Article", "Текст");
regGS("Publish", "Објави");
regGS("Unpublish", "Повуци");
regGS("Unlock", "Откључај");
regGS("Uploaded", "Аплоудован");
regGS("(yyyy-mm-dd)", "(гггг-мм-дд)");
regGS("YYYY-MM-DD", "ГГГГ-ММ-ДД");
regGS("Submit", "Пошаљи");
regGS("Image", "Слика");
regGS("Description", "Опис");
regGS("Photographer", "Фотограф");
regGS("Place", "Место");
regGS("Date", "Датум");
regGS("Thumbnail", "Мала слика");
regGS("In use", "Употребљен");
regGS("Additional searches", "Додатне претраге");
regGS("Most Recently Added", "Најновије додате");
regGS("Most Recently Modified", "Најскорије мењане");
regGS("$1 images found", "Пронађено/а је $1 слика");
regGS("Reset search conditions", "Поништи услове претраге");
regGS("Image number", "Број слике");
regGS("Users", "Корисници");
regGS("Restart the template engine", "Рестартуј шаблон-машину");
regGS("The template engine was (re)started.", "Шаблон-машина је рестартована.");
regGS("The template engine could not be restarted! Please verify if the template engine was started by other user than $1.", "Шаблон-машина не може бити рестартована! Проверите да ли је шаблон-машина стартована од стране корсника који није $1.");
regGS("Localizer", "Локализатор");
regGS("Adding new translation", "Додавање новог превода");
regGS("No more languages.", "Нема више језика");
regGS("The $1 field may only contain letters, digits and underscore (_) character.", "Поље $1 може садржати искључиво слова, бројке и доњу црту (_).");
regGS("Add new publication", "Додај нову публикацију");
regGS("Upload new template", "Аплоудуј нови шаблон");
regGS("Add new staff member", "Додај новог сарадника");
regGS("Add new subscriber", "додај новог претплатника");
regGS("Add new user type", "Додај нови тип корисника");
regGS("Add new article type", "Додај нови тип текста");
regGS("Add new country", "Додај државу");
regGS("Add new language", "Додај језик");
regGS("View logs", "Прикажи логове");
regGS("Change your password", "Промени лозинку");
regGS("Your Articles", "Твоји текстови");
regGS("Submitted Articles", "Предати текстови");
regGS("Logs", "Логови");
regGS("There are $1 article(s) left.", "Преоста(л)о је $1 текст(ова)");
regGS("There are $1 issues(s) left.", "Преостало је $1 издања");
regGS("There are $1 section(s) left.", "Преоста(л)о је $1 рубрика");
regGS("There are $1 publication(s) left.", "Преостало(а) је $1 публикација");
regGS("There are $1 countries left.", "Преостало је $1 држава");
regGS("Name <SMALL>(click to edit)</SMALL>", "Име<br><small>(клик за уређивање)</small>");
regGS("Add new subscription", "Додај нову претплату");
regGS("You do not have the right to add subscriptions.", "Немате право да додајете претплате");
regGS("Adding subscription", "Додавање претплате");
regGS("Delete subscription", "Обриши претплату");
regGS("You do not have the right to delete subscriptions.", "Немате право да бришете претплате");
regGS("No such subscription.", "Нема такве претплате");
regGS("Yes", "Да");
regGS("No", "Не");
regGS("Close", "Затвори");
regGS("No issues.", "Нема издања");
regGS("Back to Edit Article", "Назад на детаље текста");
regGS("No topics", "Нема тема");
regGS("You must fill in the $1 field.", "Морате попунити поље $1");
regGS("You do not have the right to add articles.", "Немате право да додајете чланке");
regGS("Start", "Почетак");
regGS("Days", "Дана");
regGS("(YYYY-MM-DD)", "(ГГГГ-ММ-ДД)");
regGS("The sections could not be added successfully. Some of them were already added !", "Рубрике не могу бити додате. Неке од њих већ постоје!");
regGS("Add another", "Настави са додавањем");
regGS("Cancel", "Поништи");
regGS("Done", "Готово");
regGS("OK", "OK");
regGS("Save", "Сними");
regGS("Search", "Тражи");
regGS("Make a selection", "Изаберите");
regGS("You must input a number greater than 0 into the $1 field.", "Морате унети број већи од 0 у поље $1");
regGS("You must input a valid date.", "Морате исправно унети датум");
regGS("Add new field", "Додај ново поље");
regGS("Article automatic publishing schedule", "Распоред аутоматског објављивања чланака");
regGS("Are you sure you want to delete this scheduled action?", "Да ли сте сигурни да желите да обришете заказану акцију?");
regGS("Unlink", "Поништи линк");
regGS("Are you sure you want to delete the image \'$1\'?", "Да ли сте сигурни да желите да обришете слику \'$1\'?");
regGS("No such issue.", "Нема тог издања.");
regGS("Are you sure you want to delete the subscription to the publication $1?", "Да ли сте сигурни да желите да обришете претплату на публикацију $1? ");
regGS("Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.", "Промена у издању $1 не може бити снимљена. Проверите да ли УРЛ име издања '$2'није већ коришћено у публикацији $3.");
regGS("GB", "ГБ");
regGS("MB", "МБ");
regGS("KB", "КБ");
regGS("bytes", "бајтова");
regGS("Attach", "Прикачи");
regGS("Back", "Назад");
regGS("File", "Фајл");
regGS("Save and Close", "Сними и затвори");
regGS("Add", "Додај");
regGS("Select All", "Изабери све");
regGS("Select None", "Изабери ниједан");
regGS("Add Event", "Додајте акцију");
regGS("N/A", "без података");
regGS("On Front Page", "На првој страни");
regGS("On Section Page", "На страни рубрике");
regGS("Created by", "Креирао:");
regGS("Creation date", "Датум креирања");
regGS("Publication List", "Листа публикација");
regGS("Issue List", "Листа издања");
regGS("Section List", "Листа рубрика");
regGS("All", "Све");
regGS("duplicate", "дуплирај");
regGS("move", "премести");
regGS("Move", "Премести");
regGS("From:", "Од:");
regGS("Date:", "Датум");
regGS("Hidden", "Скривен");
regGS("Comments", "Коментари");
regGS("Comment", "Коментар");
regGS("Approved", "Одобрен");
regGS("Comment:", "Коментар");
regGS("Subject:", "Наслов:");
regGS("Subject", "Наслов");
regGS("Name:", "Име:");
regGS("IP address:", "IP адреса:");
regGS("Email:", "E-mail:");
regGS("Author:", "Аутор:");
regGS("Author", "Аутор");
regGS("Article name", "Наслов текста");
regGS("Hide article", "Сакриј текст");
regGS("Show article", "Прикажи текст");
regGS("Article Type Fields", "Поља типа чланка");
regGS("Article Images", "Слике у чланцима");
regGS("Log Messages", "Лог поруке");
regGS("Article Files", "Фајлови уз чланак");
regGS("Article Comments", "Коментари на текст");
regGS("Are you sure you want to deactivate the subscription?", "Да ли сте сигурни да желите да деактивирате претплату?");
regGS("Are you sure you want to activate the subscription?", "Да ли сте сигурни да желите да активирате претплату?");
regGS("Other", "Друго");
regGS("Time:", "Време:");
regGS("No events.", "Нема догађаја");
regGS("Default templates", "Подразумевани шаблон");
regGS("System Preferences", "Системске поставке");
regGS("The date must be in the future.", "Датум мора бити у будућности");
regGS("Send", "Пошаљи");
regGS("Thank you.", "Хвала");
regGS("Please take a minute to send us an email.", "Молимо Вас да одбвојите који минут и пошаљете на имејл");
regGS("(optional)", "(опционо)");
regGS("The URL you entered is invalid: '$1'", "УРЛ који сте унели је неважећи: '$1'");
regGS("User name", "Корисничко име");
regGS("User Types", "Типови корисника");
regGS("Add new user account", "Додај новог корисника");
regGS("Schedule a new publish action", "Закажи нову акцију објављивања");
regGS("User may add/change user accounts and passwords", "Корисник може да додаје/мења корисничке налоге и лозинке");
regGS("User may delete user accounts", "Корисник може да брише корисничке налоге");
regGS("Are you sure you want to delete the image \\'$1\\'?", "Да ли сте сигурни да желите да обришете слику \\'$1\\'?");
?>
